@@ -600,8 +600,6 @@ object TableCommands {
     AnalyzeColumn,
     AnalyzePartition,
     AnalyzeTable,
-    AnalyzeTable.copy(classname =
-      "org.apache.spark.sql.execution.command.AnalyzeTablesCommand"),
     AppendDataV2,
     CacheTable,
     CacheTableAsSelect,
