@@ -96,10 +96,11 @@ class KyuubiSyncThriftClient private (
               remoteEngineBroken = false
             } catch {
               case e: Throwable =>
-                warn(s"The engine[$engineId] alive probe fails", e)
+                val engineIdStr = engineId.getOrElse("")
+                warn(s"The engine[$engineIdStr] alive probe fails", e)
                 val now = System.currentTimeMillis()
                 if (now - engineLastAlive > engineAliveTimeout) {
-                  error(s"Mark the engine[$engineId] not alive with no recent alive probe" +
+                  error(s"Mark the engine[$engineIdStr] not alive with no recent alive probe" +
                     s" success: ${now - engineLastAlive} ms exceeds timeout $engineAliveTimeout ms")
                   remoteEngineBroken = true
                 }
